@@ -1,7 +1,7 @@
 package Perinci::Access::Schemeless;
 
 our $DATE = '2015-03-06'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $VERSION = '0.81'; # VERSION
 
 use 5.010001;
 use strict;
@@ -414,7 +414,7 @@ sub get_code {
         # we don't need to wrap
         if (!$self->{wrap} ||
                 $meta->{"x.perinci.sub.wrapper.logs"} &&
-                    (first {$_->{validate}}
+                    (first {$_->{validate_args}}
                          @{ $meta->{"x.perinci.sub.wrapper.logs"} })
             ) {
             $code = \&{$name};
@@ -1020,7 +1020,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2015-03-06.
+This document describes version 0.81 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2015-03-06.
 
 =head1 DESCRIPTION
 
